@@ -4,18 +4,18 @@ function _aws_cdk_aws_s3_deployment_StorageClass(p) {
 }
 function _aws_cdk_aws_s3_deployment_UserDefinedObjectMetadata(p) {
 }
-function _aws_cdk_aws_s3_deployment_DeploymentSourceContext(p) {
-}
 function _aws_cdk_aws_s3_deployment_SourceConfig(p) {
 }
+function _aws_cdk_aws_s3_deployment_DeploymentSourceContext(p) {
+}
 function _aws_cdk_aws_s3_deployment_ISource(p) {
 }
 function _aws_cdk_aws_s3_deployment_BucketDeployment(p) {
 }
-function _aws_cdk_aws_s3_deployment_Source(p) {
-}
 function _aws_cdk_aws_s3_deployment_Expires(p) {
 }
+function _aws_cdk_aws_s3_deployment_Source(p) {
+}
 function _aws_cdk_aws_s3_deployment_CacheControl(p) {
 }
 function _aws_cdk_aws_s3_deployment_BucketDeploymentProps(p) {
@@ -49,5 +49,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_s3_deployment_ServerSideEncryption, _aws_cdk_aws_s3_deployment_StorageClass, _aws_cdk_aws_s3_deployment_UserDefinedObjectMetadata, _aws_cdk_aws_s3_deployment_DeploymentSourceContext, _aws_cdk_aws_s3_deployment_SourceConfig, _aws_cdk_aws_s3_deployment_ISource, _aws_cdk_aws_s3_deployment_BucketDeployment, _aws_cdk_aws_s3_deployment_Source, _aws_cdk_aws_s3_deployment_Expires, _aws_cdk_aws_s3_deployment_CacheControl, _aws_cdk_aws_s3_deployment_BucketDeploymentProps };
+module.exports = { print, _aws_cdk_aws_s3_deployment_ServerSideEncryption, _aws_cdk_aws_s3_deployment_StorageClass, _aws_cdk_aws_s3_deployment_UserDefinedObjectMetadata, _aws_cdk_aws_s3_deployment_SourceConfig, _aws_cdk_aws_s3_deployment_DeploymentSourceContext, _aws_cdk_aws_s3_deployment_ISource, _aws_cdk_aws_s3_deployment_BucketDeployment, _aws_cdk_aws_s3_deployment_Expires, _aws_cdk_aws_s3_deployment_Source, _aws_cdk_aws_s3_deployment_CacheControl, _aws_cdk_aws_s3_deployment_BucketDeploymentProps };
 module.exports.DeprecationError = DeprecationError;
